#!/bin/bash

: "${PORT:=8880}"
: "${CONTROL_PORT:=8881}"

echo "======================================================================"
echo "CHT-PDD env: ${CHT_ENV} server.sh starting..."

export TZ=UTC
JMX_ARGS="-Dcom.sun.management.jmxremote \
-Dcom.sun.management.jmxremote.authenticate=false \
-Dcom.sun.management.jmxremote.ssl=false \
-Dcom.sun.management.jmxremote.local.only=false \
-Dcom.sun.management.jmxremote.port=1099 \
-Dcom.sun.management.jmxremote.rmi.port=1099 \
-Djava.rmi.server.hostname=127.0.0.1 "

LOG_CONF="log4j2.xml"
export SPARK_OPTS="-Dlog4j2.configurationFile=$LOG_CONF -Dspark.executor.memoryOverhead=$SPARK_EXECUTOR_MEM \
-Dspark.driver.memory=$SPARK_DRIVER_MEM -Dspark.driver.memoryOverhead=$SPARK_MEM_OVERHEAD \
-Dspark.memory.storageFraction=0.3 -Dspark.network.timeout=400 -Dspark.sql.broadcastTimeout=$BROADCAST_TIMEOUT \
-Dspark.sql.autoBroadcastJoinThreshold=$BROADCAST_THRESHOLD"

export JAVA_OOM_OPTS="-XX:+ExitOnOutOfMemoryError -XX:+CrashOnOutOfMemoryError"
export JVM_GC_OPTS="-XX:+UseG1GC -XX:InitiatingHeapOccupancyPercent=35 -Xlog:gc*=warning"
export JAVA_BASE_ARGS="$JAVA_OPTS $JAVA_OOM_OPTS $JAVA_MEMORY_ARGS -Xmx$JAVA_HEAP_MAX -Xms$JAVA_HEAP_MIN $JVM_GC_OPTS -verbose:gc -XshowSettings:vm"

export SPARK_EVENTLOG_ENABLED=false # can enable to true from the pod if needed
export SPARK_EVENTLOG_DIR=file:/tmp/spark-events

echo "printing rabbit host env vars"
# RabbitMQ:
# in production and staging, we would use RABBITMQ_USERNAME/PASSWORD injected by
# the secret from the Jenkinsfile.
# for dev, we use the "local" RabbitMQ broker which is a POD co-deployed in your
# NG k8s dev env. Here, the env vars are $NG_RABBITMQ_USERNAME/PASSWORD (note the
# "NG_" prefix).
env | grep RABBIT | grep HOST

echo "printing redis and kafka env vars"
env | grep REDIS
env | grep KAFKA

echo "Using rabbit host=$NG_RABBITMQ_HOST user=$NG_RABBITMQ_USERNAME"

TMP_DIR=/tmp
if [ ! -d /tmp ] ; then
    mkdir /tmp
fi
echo "timedigest input location: ${TIMEDIGEST_LOC}"
echo "PDD output location: ${PDD_OUTPUT_LOC}"
echo "goldset root: ${GOLDSET_ROOT_LOC}"
echo "config: ${CONFIG}"
echo "offload: $VLC_OFFLOAD_CONFIG"

java $JAVA_BASE_ARGS $JMX_ARGS $CONFIG $SPARK_OPTS \
  -cp $JAR_FILENAME \
  com.cloudhealthtech.pdd.PDD \
  server \
  --s3creds $SVC_AWS_AUTH_MODE \
  --dbcreds $DB_CREDS \
  --kafka $KAFKA_HOST \
  --redis $REDIS_HOST \
  --tmpdir $TMP_DIR \
  --rabbiturl $NG_RABBITMQ_HOST \
  --rabbitpass $NG_RABBITMQ_PASSWORD \
  --rabbituser $NG_RABBITMQ_USERNAME \
  --rbenv $RB_ENV \
  --clusterid $K8S_NS \
  --nonce 42 \
  --local \
  --threadPool $THREADPOOL \
  --slaves $SLAVES \
  --capacityPerSlave $CAPACITY_PER_SLAVE \
  --timedigestroot $TIMEDIGEST_LOC \
  --pddoutputroot $PDD_OUTPUT_LOC \
  --goldsetroot $GOLDSET_ROOT_LOC \
  --queuename $QUEUE_NAME \
  $VLC_OFFLOAD_CONFIG \
  --dbConnPoolProperties poolType=hikari;minPoolSize=0;maxPoolSize=1;maxConnectionAge=3600;maxIdleTime=600;idleConnectionTestPeriod=60;maxStatements=256

